package ui

import (
	t_ui "icdb/pkg/types/ui"
	"image/color"

	"gioui.org/layout"
	"gioui.org/text"
	"gioui.org/widget/material"
)

// renderView dynamically loads the selected view
func renderView(th *material.Theme) layout.Widget {
	return func(gtx layout.Context) layout.Dimensions {
		switch currentView {
		case t_ui.UIViewMain:
			return renderMainView(gtx, th)
		case t_ui.UIViewParts:
			return renderPartsView(gtx, th)
		case t_ui.UIViewSettings:
			return renderSettingsView(gtx, th)
		default:
			return renderMainView(gtx, th)
		}
	}
}

// renderMainView displays the main view
func renderMainView(gtx layout.Context, th *material.Theme) layout.Dimensions {
	title := material.H1(th, "Welcome to ICDB")
	title.Color = color.NRGBA{R: 127, G: 0, B: 0, A: 255}
	title.Alignment = text.Middle
	return title.Layout(gtx)
}

// renderPartsView displays the parts list
func renderPartsView(gtx layout.Context, th *material.Theme) layout.Dimensions {
	title := material.H1(th, "Parts Management")
	title.Alignment = text.Middle
	return title.Layout(gtx)
}

// renderSettingsView displays the settings view
func renderSettingsView(gtx layout.Context, th *material.Theme) layout.Dimensions {
	title := material.H1(th, "Settings")
	title.Alignment = text.Middle
	return title.Layout(gtx)
}
